flit_core: Distribution-building parts of Flit. See flit package for more information
=====================================================================================

Description
-----------

Distribution-building parts of Flit. See flit package for more information

License
-------

Upstream Contact
----------------

https://pypi.org/project/flit-core/

